.jPicker{box-sizing:content-box}.jPicker label{display:inline}.jPicker .Icon{display:inline-block;height:24px;position:relative;text-align:left;width:25px}.jPicker .Icon span.Color,.jPicker .Icon span.Alpha{background-position:2px 2px;display:block;height:100%;left:0;position:absolute;top:0;width:100%;box-sizing:border-box}.jPicker .Icon span.Image{background-repeat:no-repeat;cursor:pointer;display:block;height:100%;left:0;position:absolute;top:0;width:100%}.jPicker.Container{color:#000;z-index:10}table.jPicker{font-family:Arial,Helvetica,Sans-Serif;font-size:12px!important;margin:0;padding:0;width:545px;z-index:20}.jPicker hr{margin:7px 0}.jPicker .Move{background-color:#ddd;border-color:#fff #666 #666 #fff;border-style:solid;border-width:1px;cursor:move;height:12px;padding:0;box-sizing:border-box}.jPicker .Title{display:none}.jPicker div.Map{border-bottom:2px solid #fff;border-left:2px solid #9a9a9a;border-right:2px solid #fff;border-top:2px solid #9a9a9a;cursor:crosshair;height:260px;margin:0 10px 10px;overflow:hidden;padding:0;position:relative;width:260px;box-sizing:border-box}.jPicker div.Bar{box-sizing:border-box;border-bottom:2px solid #fff;border-left:2px solid #9a9a9a;border-right:2px solid #fff;border-top:2px solid #9a9a9a;cursor:n-resize;height:260px;margin:-11px 10px 0 5px;overflow:hidden;padding:0;position:relative;width:24px}.jPicker .Map .Map1,.jPicker .Map .Map2,.jPicker .Map .Map3,.jPicker .Bar .Map1,.jPicker .Bar .Map2,.jPicker .Bar .Map3,.jPicker .Bar .Map4,.jPicker .Bar .Map5,.jPicker .Bar .Map6{background-color:transparent;background-image:none;display:block;left:0;position:absolute;top:0}.jPicker .Map .Map1,.jPicker .Map .Map2,.jPicker .Map .Map3{height:2596px;width:256px}.jPicker .Bar .Map1,.jPicker .Bar .Map2,.jPicker .Bar .Map3,.jPicker .Bar .Map4{height:3896px;width:20px}.jPicker .Bar .Map5,.jPicker .Bar .Map6{height:256px;width:20px}.jPicker .Map .Map1,.jPicker .Map .Map2,.jPicker .Bar .Map6{background-repeat:no-repeat}.jPicker .Map .Map3,.jPicker .Bar .Map5{background-repeat:repeat}.jPicker .Bar .Map1,.jPicker .Bar .Map2,.jPicker .Bar .Map3,.jPicker .Bar .Map4{background-repeat:repeat-x}.jPicker .Map .Arrow{display:block;position:absolute}.jPicker .Bar .Arrow{display:block;left:0;position:absolute}.jPicker .Preview{font-size:9px;padding:5px 0 0;text-align:center}.jPicker .Preview>div{box-sizing:border-box;border:2px inset #eee;height:62px;margin:0 auto;padding:0;width:62px}.jPicker .Preview>div>span{box-sizing:border-box;border:1px solid #000;display:block;height:30px;margin:0 auto;padding:0;width:60px}.jPicker .Preview .Active{border-bottom-width:0}.jPicker .Preview .Current{border-top-width:0;cursor:pointer}.jPicker input{font-size:13px}.jPicker .Button{box-sizing:border-box;text-align:center;padding:0 4px;width:115px}.jPicker .Button input{box-sizing:border-box;padding:2px 0;width:100px}.jPicker .Button .Ok{margin:12px 0 5px}.jPicker td{margin:0;padding:0}.jPicker td.Radio{margin:0;padding:0;width:32px}.jPicker td.Radio input{margin:0 5px 0 0;padding:0;display:inline-block}.jPicker td.Text{font-size:12px!important;height:22px;margin:0;padding:0;text-align:left;width:70px}.jPicker tr.Hex td.Text{width:100px}.jPicker td.Text input{box-sizing:border-box;background-color:#fff;border:1px inset #aaa;height:19px;margin:0 0 0 5px;text-align:left;width:30px}.jPicker tr.Hex td.Text input.Hex{width:45px;display:inline-block;margin-left:2px;text-align:center}.jPicker.no-alpha-picker tr.Hex td.Text input.Hex{width:50px;margin-left:5px}.jPicker tr.Hex td.Text input.AHex{width:16px;text-align:center}.jPicker.no-alpha-picker tr.Hex td.Text input.AHex{display:none}.jPicker.no-alpha-picker tr.Alpha{visibility:hidden}.jPicker .Grid{text-align:center;width:102px;overflow:hidden}.jPicker .Grid span.QuickColor{box-sizing:border-box;border:1px inset #aaa;cursor:pointer;display:inline-block;height:15px;margin:0;padding:0;width:17px;float:left}@media all{#jPicker{margin:0 8px;text-align:left}#jPicker ul{font-size:15px;margin:0 0 0 15px;padding:0}#jPicker ul li{list-style:disc;padding:2px 0}#jPicker ul li ul{margin-bottom:10px}#jPicker ul li ul li{list-style:circle}#jPicker p{font-size:13px;padding:0 10px}#jPicker hr{clear:both}#jPicker h2.jPicker{font-size:16px;padding:20px 10px}#jPicker code{color:#8bd;font-size:14px;font-weight:700}#jPicker pre{background:#eee;border:1px solid #000;color:#000;display:block;font-size:11px;margin:10px 5px;padding:5px}#jPicker span{font-size:13px;text-align:center}#jPicker a{color:#ff8050}#jPicker input{font-size:13px;padding:2px 5px}#jPicker h2{font-size:16px;margin:10px 0}}