webshims.validityMessages.it={typeMismatch:{email:"Inserire un indirizzo e-mail",url:"Inserire un URL"},badInput:{number:"Valore non valido.",date:"Valore non valido.",time:"Valore non valido.",range:"Valore non valido.","datetime-local":"Valore non valido."},tooLong:"Valore non valido.",patternMismatch:"Inserire un valore nel formato richiesto: {%title}",valueMissing:{defaultMessage:"Compilare questo campo",checkbox:"Selezionare questa casella per procedere",select:"Selezionare un elemento dall'elenco",radio:"Selezionare una delle opzioni disponibili"},rangeUnderflow:{defaultMessage:"Il valore deve essere superiore o uguale a {%min}.",date:"Il valore deve essere superiore o uguale a {%min}.",time:"Il valore deve essere superiore o uguale a {%min}.","datetime-local":"Il valore deve essere superiore o uguale a {%min}."},rangeOverflow:{defaultMessage:"Il valore deve essere inferiore o uguale a {%max}.",date:"Il valore deve essere inferiore o uguale a {%max}.",time:"Il valore deve essere inferiore o uguale a {%max}.","datetime-local":"Il valore deve essere inferiore o uguale a {%max}."},stepMismatch:"Valore non valido."},webshims.formcfg.it={numberFormat:{".":".",",":","},numberSigns:".",dateSigns:"/",timeSigns:":. ",dFormat:"/",patterns:{d:"dd/mm/yy"},date:{closeText:"Chiudi",prevText:"&#x3C;Prec",nextText:"Succ&#x3E;",currentText:"Oggi",monthNames:["Gennaio","Febbraio","Marzo","Aprile","Maggio","Giugno","Luglio","Agosto","Settembre","Ottobre","Novembre","Dicembre"],monthNamesShort:["Gen","Feb","Mar","Apr","Mag","Giu","Lug","Ago","Set","Ott","Nov","Dic"],dayNames:["Domenica","Luned\xec","Marted\xec","Mercoled\xec","Gioved\xec","Venerd\xec","Sabato"],dayNamesShort:["Dom","Lun","Mar","Mer","Gio","Ven","Sab"],dayNamesMin:["Do","Lu","Ma","Me","Gi","Ve","Sa"],weekHeader:"Sm",firstDay:1,isRTL:!1,showMonthAfterYear:!1,yearSuffix:""}};